==> locus-0.84.tar.gz: locus-0.84/bin/cruncher/crunopt.cpp <==
#include "myfndt.h"
#include "crunopt.h"
#include "offind.h"
#include "otxtrpt.h"
#include "ostoplst.h"
#include "ocross.h"
#include "owordsiv.h"
#include "ocache.h"
#include "ocrunout.h"

static int GetClusterCounter(COptions<int> *Options, const char *);
static int GetReserveCounter(COptions<int> *Options, const char *);

const int CCruncherOptions::DocDirLimit = 5;
const int CCruncherOptions::DocDirDelta = 5;
const int CCruncherOptions::DocMaskLimit = 5;
const int CCruncherOptions::DocMaskDelta = 5;

CCruncherOptions::CCruncherOptions(const DString &ExeDrive):
	CLocusOptions(ExeDrive)
{
	CStringListValue DocDirList(DocDirLimit, DocDirDelta);
	Add(O_DOCDIR, DocDirList);
	CStringListValue DocMaskList(DocMaskLimit, DocMaskDelta);
	Add(O_MASK, DocMaskList);

	Add(T_FINDERFORMAT_DDN, "searching for %d. file (%d%%)\n");
	Add(T_INDEXERFORMAT_DDN, "indexing (%d. cycle, %d%%)\n");
	Add(T_READERFORMAT_DDN, "reading %d. file (%d%%)\n");
	Add(T_SORTERFORMAT_DDN, "s. %d %d\n");

    Add(O_FINDCOUNTER, 10);
    Add(O_READCOUNTER, 1000);
    Add(O_INDEXCOUNTER, 400);

	Add(O_STOPLISTSRC, "");
	Add(O_STOPLIST, GetFileName);

	Add(O_USERCLUSTERCOUNTER, 8);
	Add(O_NRMCLUSTERCOUNTER, GetClusterCounter);
	Add(O_RESERVECOUNTER, GetReserveCounter);

	Add(O_DOCMAXLEN, 0);
	Add(O_MAXWORDLEN, 100);
	Add(O_OCCBLOCKSIZE, 8000);
/* profile 26. 12. 96 (Linux): 1 file, 949 250 bytes
	200		13 min
	1000		9.5 min
	2000		9 min 
	3500		9 min
	5000		9 min 

	29. 12: OccBlockSize = 2000
	under X		11 min 
	bash		9 min */
/* profile 1. 5. 97 (Linux): 8 830 857 bytes of pgw (with a stop list),
		reference-counted strings, sort in STL tree
	2000		93 min
	3000		85 min */
/* profile 15. 8. 97 (Linux):
	2 383 600 bytes with a stop list
		w/o stemming	stemming
	3000	13 min		18 min
	5000	x		15 min
	8000	10 min		13 min */

	WatchSection("cruncher");
}

CCruncherOptions::~CCruncherOptions()
{
}

DString CCruncherOptions::FirstInvalidKey()
{
	DString Key = CLocusOptions::FirstInvalidKey();
	if (!Key.IsEmpty())
		return Key;

	CStringListValue SourceDirList =
			COptions<CStringListValue>::Get(O_DOCDIR);
	if (SourceDirList.IsEmpty())
		return DString(O_DOCDIR);

	CStringListValue SourceMaskList =
			COptions<CStringListValue>::Get(O_MASK);
	if (SourceMaskList.IsEmpty())
		return DString(O_MASK);

	return Key;
}

static int GetClusterCounter(COptions<int> *Options, const char *)
{
	int ClusterCounter = Options->Get(O_USERCLUSTERCOUNTER);
	if (ClusterCounter <= 1)
		return 1;
	else
		return ClusterCounter >= 1000 ? 1000 : ClusterCounter;
}

static int GetReserveCounter(COptions<int> *Options, const char *)
{
    return 1000;// should be computed from size of unsigned short,
	// DString::MaxAllowedLength and average word length
}

==> locus-0.88.tar.gz: locus-0.88/bin/cruncher/crunopt.cpp <==
#include "myfndt.h"
#include "crunopt.h"
#include "cocc.h"
#include "occmap.h"
#include "offind.h"
#include "otxtrpt.h"
#include "ostoplst.h"
#include "ocross.h"
#include "owordsiv.h"
#include "ocache.h"
#include "ocrunout.h"

static int GetClusterCounter(COptions<int> *Options, const char *);
static int GetReserveCounter(COptions<int> *Options, const char *);

const int CCruncherOptions::DocDirLimit = 5;
const int CCruncherOptions::DocDirDelta = 5;
const int CCruncherOptions::DocMaskLimit = 5;
const int CCruncherOptions::DocMaskDelta = 5;

CCruncherOptions::CCruncherOptions(const DString &ExeDrive):
	CLocusOptions(ExeDrive)
{
	CStringListValue DocDirList(DocDirLimit, DocDirDelta);
	Add(O_DOCDIR, DocDirList);
	CStringListValue DocMaskList(DocMaskLimit, DocMaskDelta);
	Add(O_MASK, DocMaskList);

	Add(T_FINDERFORMAT_DDN, "searching for %d. file (%d%%)\n");
	Add(T_INDEXERFORMAT_DDN, "indexing (%d. cycle, %d%%)\n");
	Add(T_READERFORMAT_DDN, "reading %d. file (%d%%)\n");
	Add(T_SORTERFORMAT_DDN, "s. %d %d\n");

	Add(O_FINDCOUNTER, 10);
	Add(O_READCOUNTER, 1500);
	Add(O_INDEXCOUNTER, 400);

	Add(O_STOPLISTSRC, "");
	Add(O_STOPLIST, GetFileName);

	Add(O_USERCLUSTERCOUNTER, 8);
	Add(O_NRMCLUSTERCOUNTER, GetClusterCounter);
	Add(O_RESERVECOUNTER, GetReserveCounter);

	Add(O_DOCMAXLEN, 0);
	Add(O_MAXWORDLEN, 100);
	Add(O_OCCCOLSIZE, 60000);
	Add(O_OCCBLOCKSIZE, 40000);
/* profile 2Aug98:
9 772 883 bytes in 6 files (Gibbon):
col size	block size	time	size
  8000		  8000		26 min	6 600 450 bytes
 30000		 20000		19 min	6 669 162 bytes
 60000		 40000		16 min	6 282 914 bytes

169 005 876 bytes in 381 files (UF texts):
col size	block size	time	size
 60000		 40000		8:40	66 602 752 bytes

Obsolete profiling times for O_OCCBLOCKSIZE are at the end
of the file.
*/

	WatchSection("cruncher");
}

CCruncherOptions::~CCruncherOptions()
{
}

DString CCruncherOptions::FirstInvalidKey()
{
	DString Key = CLocusOptions::FirstInvalidKey();
	if (!Key.IsEmpty())
		return Key;

	CStringListValue SourceDirList =
			COptions<CStringListValue>::Get(O_DOCDIR);
	if (SourceDirList.IsEmpty())
		return DString(O_DOCDIR);

	CStringListValue SourceMaskList =
			COptions<CStringListValue>::Get(O_MASK);
	if (SourceMaskList.IsEmpty())
		return DString(O_MASK);

    COccColData AnyOccCol;
    int OccColSize = COptions<int>::Get(O_OCCCOLSIZE);
    if (OccColSize <= 0 || OccColSize > AnyOccCol.max_size())
		return DString(O_OCCCOLSIZE);

    int OccBlockSize = COptions<int>::Get(O_OCCBLOCKSIZE);
    COccBlock AnyOccBlock(OccBlockSize);
    if (OccBlockSize <=0 || OccBlockSize > AnyOccBlock.max_size())
		return DString(O_OCCBLOCKSIZE);

	return Key;
}

static int GetClusterCounter(COptions<int> *Options, const char *)
{
	int ClusterCounter = Options->Get(O_USERCLUSTERCOUNTER);
	if (ClusterCounter <= 1)
		return 1;
	else
		return ClusterCounter >= 1000 ? 1000 : ClusterCounter;
}

static int GetReserveCounter(COptions<int> *Options, const char *)
{
    return 1000;// should be computed from size of unsigned short,
	// DString::MaxAllowedLength and average word length
}

/* obsolete profiling times for O_OCBLOCKSIZE:
profile 15. 8. 97 (Linux):
	2 383 600 bytes with a stop list
		w/o stemming	stemming
	3000	13 min		18 min
	5000	x		15 min
	8000	10 min		13 min
profile 1. 5. 97 (Linux): 8 830 857 bytes of pgw (with a stop list),
		reference-counted strings, sort in STL tree
	2000		93 min
	3000		85 min
profile 26. 12. 96 (Linux): 1 file, 949 250 bytes
	200		13 min
	1000		9.5 min
	2000		9 min 
	3500		9 min
	5000		9 min 

	29. 12: OccBlockSize = 2000
	under X		11 min 
	bash		9 min
*/
